@@ -9,9 +9,12 @@ apt-get update -qy && apt-get install -qy --no-install-recommends \
     bison \
     cvs \
     flex \
+    pypy \
     python2.7 \
     python3 \
     python-pip \
+    subversion \
+    time \
     xmlto \
  && apt-get clean \
  && rm -rf /var/lib/apt/lists/*
