@@ -7,7 +7,7 @@ trap "rm -rf /tmp/test-repo$$ /tmp/target$$ /tmp/out$$" 0 12 2 15
 
 ./hg-to-fi -n /tmp/test-repo$$ < simple.fi
 cd /tmp/test-repo$$
-repotool checkout /tmp/target$$ lightweight-sample
+repotool checkout -t lightweight-sample /tmp/target$$
 echo Return code: $? >/tmp/out$$
 cd - >/dev/null
 ./dir-md5 /tmp/target$$ >>/tmp/out$$
@@ -17,6 +17,8 @@ case $1 in
         diff --text -u $2.chk /tmp/out$$ || exit 1; ;;
     --rebuild)
 	cat /tmp/out$$ >$2.chk;;
+    --view)
+	cat /tmp/out$$;;
 esac
 	      
 #end
