@@ -14,6 +14,8 @@ case $1 in
         diff --text -u $2.chk /tmp/out$$ || exit 1; ;;
     --rebuild)
 	cat /tmp/out$$ >$2.chk;;
+    --view)
+	cat /tmp/out$$;;
 esac
 	      
 #end
