@@ -1,4 +1,4 @@
-## Test listing tags in a git repository
+## Test listing tags in git repository
 
 command -v git >/dev/null 2>&1 || { echo "    Skipped, git missing."; exit 0; }
 
@@ -13,5 +13,7 @@ case $1 in
         diff --text -u $2.chk /tmp/out$$ || exit 1; ;;
     --rebuild)
 	cat /tmp/out$$ >$2.chk;;
+    --view)
+	cat /tmp/out$$;;
 esac
 	      
